require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_addomain',
  dscmeta_resource_friendly_name: 'ADDomain',
  dscmeta_resource_name: 'MSFT_ADDomain',
  dscmeta_module_name: 'ActiveDirectoryDsc',
  dscmeta_module_version: '4.0.0.0',
  docs: 'The DSC ADDomain resource type.
         Automatically generated from version 4.0.0.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_domainmode: {
      type: "Optional[Enum['Win2008', 'Win2008R2', 'Win2012', 'Win2012R2', 'WinThreshold']]",
      desc: 'The Domain Functional Level for the entire domain.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_dnsdelegationcredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Credential used for creating DNS delegation.',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_databasepath: {
      type: 'Optional[String]',
      desc: 'Path to a directory that contains the domain database.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_logpath: {
      type: 'Optional[String]',
      desc: 'Path to a directory for the log file that will be written.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_sysvolpath: {
      type: 'Optional[String]',
      desc: 'Path to a directory where the Sysvol file will be written.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_forestmode: {
      type: "Optional[Enum['Win2008', 'Win2008R2', 'Win2012', 'Win2012R2', 'WinThreshold']]",
      desc: 'The Forest Functional Level for the entire forest.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_domainnetbiosname: {
      type: 'Optional[String]',
      desc: 'NetBIOS name for the new domain.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_domainname: {
      type: 'String',
      desc: 'The fully qualified domain name (FQDN) of the new domain.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_credential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Specifies the user name and password that corresponds to the account used to install the domain controller.',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_safemodeadministratorpassword: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: 'Password for the administrator account when the computer is started in Safe Mode.',
      behaviour: :parameter,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_parentdomainname: {
      type: 'Optional[String]',
      desc: 'Fully qualified domain name (FQDN) of the parent domain.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
